@@ -1,25 +1,21 @@
 from __future__ import annotations
 
-from dataclasses import dataclass, InitVar, field
-from functools import partial
 import json
 import multiprocessing as mp
-from concurrent.futures import ProcessPoolExecutor
 import traceback
-from typing import TYPE_CHECKING, Callable, Coroutine, Optional, Any
+from concurrent.futures import ProcessPoolExecutor
+from dataclasses import InitVar, dataclass, field
+from functools import partial
+from typing import TYPE_CHECKING, Any, Callable, Coroutine, Optional
+
 from typing_extensions import ParamSpec
 
-from .utils import (
-    PubSub,
-    MultiprocessingLogging,
-    run_in_process,
-    RunInProcess,
-)
+from .count import RunNoCounter
 from .process import run
-from .process.run import QueueRegistry, RunArg, QueueCommands
+from .process.run import QueueCommands, QueueRegistry, RunArg
 from .registrar import Registrar
 from .types import RunNo
-from .count import RunNoCounter
+from .utils import MultiprocessingLogging, PubSub, RunInProcess, run_in_process
 
 if TYPE_CHECKING:
     from .state import State
@@ -84,6 +80,8 @@ class Context:
         self.run_no_count = RunNoCounter(run_no_start_from)
 
     async def start(self):
+        await self.mp_logging.open()
+        await self.registrar.open()
         await self.registrar.script_change(
             script=self.statement, filename=self.filename
         )
@@ -108,9 +106,7 @@ class Context:
     ):
         if statement:
             self.statement = statement
-            await self.registrar.script_change(
-                script=statement, filename=self.filename
-            )
+            await self.registrar.script_change(script=statement, filename=self.filename)
         if run_no_start_from is not None:
             self.run_no_count = RunNoCounter(run_no_start_from)
 
