@@ -1,16 +1,14 @@
 from __future__ import annotations
+import asyncio
 
 import linecache
 from logging import getLogger
-
 from typing import Any, AsyncIterator, Optional, Tuple
 
-from .utils import merge_aiters
 from .context import Context
 from .state import Machine
-from .types import PromptNo, TraceNo, StdoutInfo
-
-from .types import RunInfo, TraceInfo, PromptInfo
+from .types import PromptInfo, PromptNo, RunInfo, StdoutInfo, TraceInfo, TraceNo
+from .utils import merge_aiters
 
 
 class Nextline:
@@ -19,18 +17,25 @@ class Nextline:
     Nextline supports concurrency with threading and asyncio. It uses multiple
     instances of Pdb, one for each thread and async task.
 
-    Note
-    ----
-    The running asyncio event loop must exists when Nextline is instantiated.
 
     Parameters
     ----------
     statement : str
         A Python code as a string
+    run_no_start_from : int, optional
+        The first run number. The default is 1.
+    timeout_on_exit : float, optional
+        The timeout in seconds to wait for the nextline to exit from the "with"
+        block. The default is 3.
 
     """
 
-    def __init__(self, statement: str, run_no_start_from: int = 1):
+    def __init__(
+        self,
+        statement: str,
+        run_no_start_from: int = 1,
+        timeout_on_exit: float = 3,
+    ):
 
         logger = getLogger(__name__)
         logger.debug(f"statement starts with {statement[:25]!r}")
@@ -40,12 +45,17 @@ class Nextline:
             run_no_start_from=run_no_start_from,
             statement=statement,
         )
+        self._timeout_on_exit = timeout_on_exit
         self._registry = self._context.registry
         self._q_commands = self._context.q_commands
 
+        self._started = False
         self._closed = False
 
     async def start(self) -> None:
+        if self._started:
+            return
+        self._started = True
         await self._context.start()
         self._machine = Machine(self._context)
         await self._machine.initialize()
@@ -69,16 +79,14 @@ class Nextline:
 
     async def __aexit__(self, exc_type, exc_value, traceback):
         del exc_type, exc_value, traceback
-        await self.close()
+        await asyncio.wait_for(self.close(), timeout=self._timeout_on_exit)
 
     async def run(self) -> None:
         """Execute the script and wait until it exits"""
         await self._machine.run()
         await self._machine.finish()
 
-    def send_pdb_command(
-        self, command: str, prompt_no: int, trace_no: int
-    ) -> None:
+    def send_pdb_command(self, command: str, prompt_no: int, trace_no: int) -> None:
         self._q_commands.put((command, PromptNo(prompt_no), TraceNo(trace_no)))
 
     def interrupt(self) -> None:
@@ -138,9 +146,7 @@ class Nextline:
         return self.subscribe("trace_nos")
 
     def get_source(self, file_name=None):
-        if not file_name or file_name == self._registry.latest(
-            "script_file_name"
-        ):
+        if not file_name or file_name == self._registry.latest("script_file_name"):
             return self.get("statement").split("\n")
         return [e.rstrip() for e in linecache.getlines(file_name)]
 
@@ -163,9 +169,7 @@ class Nextline:
     def subscribe_prompt_info(self) -> AsyncIterator[PromptInfo]:
         return self.subscribe("prompt_info")
 
-    def subscribe_prompt_info_for(
-        self, trace_no: int
-    ) -> AsyncIterator[PromptInfo]:
+    def subscribe_prompt_info_for(self, trace_no: int) -> AsyncIterator[PromptInfo]:
         return self.subscribe(f"prompt_info_{trace_no}")
 
         # Alternative implementation under development
@@ -193,9 +197,7 @@ class Nextline:
     def get(self, key) -> Any:
         return self._registry.latest(key)
 
-    def subscribe(
-        self, key, last: Optional[bool] = True
-    ) -> AsyncIterator[Any]:
+    def subscribe(self, key, last: Optional[bool] = True) -> AsyncIterator[Any]:
         return self._registry.subscribe(key, last=last)
 
     def subscribe_stdout(self) -> AsyncIterator[StdoutInfo]:
