@@ -1,24 +1,28 @@
 from __future__ import annotations
 
-import os
-from asyncio import Task
-import threading
-from threading import Thread
-from weakref import WeakKeyDictionary
-import datetime
 import dataclasses
-
-from typing import TYPE_CHECKING, Any, Callable, Optional, Tuple, Set
-from typing import Dict, MutableMapping  # noqa F401
-from typing_extensions import TypeAlias
+import datetime
+import os
+import threading
+from asyncio import Task
+from threading import Thread
 from types import FrameType
-
-from ..types import RunNo, TraceNo, PromptNo, TraceInfo, PromptInfo, StdoutInfo
-from ..utils import (
-    ThreadTaskDoneCallback,
-    ThreadTaskIdComposer,
-    current_task_or_thread,
+from typing import (  # noqa F401
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    MutableMapping,
+    Optional,
+    Set,
+    Tuple,
 )
+from weakref import WeakKeyDictionary
+
+from typing_extensions import TypeAlias
+
+from ..types import PromptInfo, PromptNo, RunNo, StdoutInfo, TraceInfo, TraceNo
+from ..utils import ThreadTaskDoneCallback, ThreadTaskIdComposer, current_task_or_thread
 from .io import peek_stdout_by_task_and_thread
 
 if TYPE_CHECKING:
@@ -54,13 +58,9 @@ class Callback:
         self._to_canonic = ToCanonic()
         self._entering_thread: Optional[Thread] = None
         self._last_prompt_frame_map: Dict[TraceNo, FrameType] = {}
-        self._current_trace_call_map: Dict[
-            TraceNo, Tuple[FrameType, str, Any]
-        ] = {}
+        self._current_trace_call_map: Dict[TraceNo, Tuple[FrameType, str, Any]] = {}
 
-    def task_or_thread_start(
-        self, trace_no: TraceNo, pdbi: PdbInterface
-    ) -> None:
+    def task_or_thread_start(self, trace_no: TraceNo, pdbi: PdbInterface) -> None:
         self.trace_start(trace_no, pdbi)
 
         task_or_thread = current_task_or_thread()
@@ -179,9 +179,7 @@ class Callback:
         self._registrar.put_prompt_info_for_trace(trace_no, prompt_info)
         self._last_prompt_frame_map[trace_no] = frame
 
-    def prompt_end(
-        self, trace_no: TraceNo, prompt_no: PromptNo, command: str
-    ) -> None:
+    def prompt_end(self, trace_no: TraceNo, prompt_no: PromptNo, command: str) -> None:
         prompt_info = self._prompt_info_map.pop((trace_no, prompt_no))
         prompt_info = dataclasses.replace(
             prompt_info,
