@@ -1,7 +1,8 @@
 from __future__ import annotations
 
+from typing import TYPE_CHECKING, Any, Optional
+
 from tblib import pickling_support  # type: ignore
-from typing import TYPE_CHECKING, Optional, Any
 
 if TYPE_CHECKING:
     from .context import Context
