@@ -1,17 +1,15 @@
 from __future__ import annotations
 
-from concurrent.futures import Executor, ProcessPoolExecutor
-from concurrent.futures.process import BrokenProcessPool
-from multiprocessing import Process
-
+import asyncio
 import os
 import signal
-import asyncio
-
+from concurrent.futures import Executor, ProcessPoolExecutor
+from concurrent.futures.process import BrokenProcessPool
 from functools import partial
+from multiprocessing import Process
 from typing import Callable, Generic, Optional, TypeVar
-from typing_extensions import ParamSpec
 
+from typing_extensions import ParamSpec
 
 _T = TypeVar("_T")
 _P = ParamSpec("_P")
@@ -25,9 +23,7 @@ async def run_in_process(
 ) -> RunInProcess[_T, _P]:
     if executor_factory is None:
         executor_factory = partial(ProcessPoolExecutor, max_workers=1)
-    return await RunInProcess.create(
-        executor_factory, func, *func_args, **func_kwargs
-    )
+    return await RunInProcess.create(executor_factory, func, *func_args, **func_kwargs)
 
 
 class RunInProcess(Generic[_T, _P]):
